==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicDesktopPaneUI__24NavigateAction.h <==
// public class javax.swing.plaf.basic.BasicDesktopPaneUI$NavigateAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 526fc5d59eb0cc7a javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction_H_
#define _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_refs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$refs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vmethods	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtable	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtype	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$method$_init$c5ed387795e3a8dc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
extern jboolean _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$method$isEnabled$93ecf19b136b3f6c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$method_info$actionPerformed$9046a9754e643ffd;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$method_info$isEnabled$93ecf19b136b3f6c;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
	jboolean	(*isEnabled$93ecf19b136b3f6c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vmethods	javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$refs {
    _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_refs	javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_nonrefs	javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object {
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtype _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicDesktopPaneUI__24NavigateAction.h <==
// public class javax.swing.plaf.basic.BasicDesktopPaneUI$NavigateAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 526fc5d59eb0cc7a javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction_H_
#define _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_refs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$refs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vmethods	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtable	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtype	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$method$_init$c5ed387795e3a8dc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$method$isEnabled$93ecf19b136b3f6c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$method_info$actionPerformed$9046a9754e643ffd;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$method_info$isEnabled$93ecf19b136b3f6c;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isEnabled$93ecf19b136b3f6c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vmethods	javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$refs {
    _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_refs	javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$sub_nonrefs	javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$object {
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$vtype _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24NavigateAction_H_ */
